<?php

/**
 * Determines what kind of blog title to generate.
 * 
 * @param string $sep The symbol to use as a separator.
 * @param bool $display To display or to return.
 * @access public
 * @return string
 */
function blogtitle($sep = '&raquo;', $display = true) {
	$title = get_bloginfo('name');
	
	// Compatibility with the Optimal Title plugin, which can be
	// downloaded at http://elasticdog.com/2004/09/optimal-title
	if ( function_exists('optimal_title') )
		$title = optimal_title($sep, false) . $title;
	
	if ( ( !function_exists('is_front_page') && is_home() ) || ( function_exists('is_front_page') && is_front_page() ) )
		$title .= " $sep " . get_bloginfo('description');
	elseif ( is_404() )
		$title .= __(" $sep 404 Not Found");
	elseif ( !function_exists('optimal_title') )
		$title .= wp_title($sep, false);
	
	if ( $display )
		echo $title;
	else
		return $title;
}

/**
 * Displays the tabbed page navigation.
 * 
 * @access public
 * @return void
 */
function page_tabs() {
	// Assemble the first tab
	$home_class = ( !function_exists('is_front_page') && is_home() ) || ( function_exists('is_front_page') && is_front_page() ) ? 'page_item current_page_item' : 'page_item';
	$home = '<li class="' . $home_class . '"><a href="' . get_option('home') . '" title="' . __('Home') . '" rel="home">' . __('Home') . '</a></li>' . "\n";
	echo $home;
	
	// Then the rest of the page tabs
	wp_list_pages('depth=1&title_li=&sort_column=post_title');
}

/**
 * Displays the post CSS class.
 * 
 * @access public
 * @return void
 */
if ( !function_exists('post_class') ) :
	function post_class() {
		global $post;
		$class = array('post');
		
		foreach ( (array) get_the_category() as $cat ) {
			if ( false !== strpos('aside', $cat->category_nicename) || false !== strpos('asides', $cat->category_nicename) ) {
				$class[] = 'aside';
				break;
			}
		}
		
		echo 'class="' . implode(' ', $class) . '"';
	}
endif;

/**
 * Displays the comment <li> CSS class.
 * 
 * @access public
 * @return void
 */
if ( !function_exists('comment_class') ) :
	function comment_class() {
		global $comment, $post, $count;
		$class = array();
		
		if ( 'trackback' != $comment->comment_type )
			$class[] = 'comment';
		else
			$class[] = 'trackback';
		
		// Registered user
		if ( $comment->user_id ) {
			$class[] = 'byuser';
			// Post author
			if ( $comment->user_id == $post->post_author )
				$class[] = 'bypostauthor';
		}
		
		// Alternate comments
		if ( $count % 2 )
			$class[] = 'alt';
		
		echo 'class="' . implode(' ', $class) . '"';
	}
endif;

/**
 * Generates the comment number depending on the current comment and comment page.
 * 
 * Not to be confused with WordPress's comments_number() function, that prints the
 * number of comments for a given post.
 * 
 * @param int &$comment_number The comment number to be generated.
 * @param bool $in_comments_loop Is this function being called in the comments loop?
 * @access public
 * @return int The generated comment number.
 * @since 1.1.0
 */
function comment_number(&$comment_number, $in_comments_loop = true) {
	if ( $in_comments_loop ) {
		if ( 'desc' == get_option('comment_order') )
			--$comment_number;
		else
			++$comment_number;
	} else {
		$page = get_query_var('cpage') ? get_query_var('cpage') : 1;
	
		if ( 'desc' == get_option('comment_order') )
			$comment_number = ( get_option('comments_per_page') * $page ) + 1;
		else
			$comment_number = get_option('comments_per_page') * ( $page - 1 );
	}
	
	return $comment_number;
}

/**#@+
 * Displays a post comment.
 * 
 * @access public
 * @return void
 * @since 1.1.0
 */
function comment_start($comment, $args, $depth) {
	global $comment_number;
	
	$GLOBALS['comment'] = $comment;
	extract($args, EXTR_SKIP);
	$add_below = 'div-comment';
	
?>
<?php if ( 'comment' == get_comment_type() ) : /* This is a comment */ ?>
<li id="comment-<?php comment_ID(); ?>" <?php comment_class(empty($args['has_children']) ? '' : 'parent'); ?>>
	<div id="div-comment-<?php comment_ID(); ?>">
		<div class="comment-author">
<?php if ( function_exists('get_avatar') ) : /* WordPress 2.5 core comes with gravatars! */ ?>
			<?php echo get_avatar(get_comment_author_email(), '50', get_bloginfo('stylesheet_directory') . '/images/gravatar_default.gif'); ?>
<?php elseif ( function_exists('gravatar') ) : /* Gravatar plugin: http://gravatar.com/site/implement */ ?>
			<img class="avatar" src="<?php gravatar('R', 50, get_bloginfo('stylesheet_directory') . '/images/gravatar_default.gif'); ?>" height="50" width="50" alt="" />
<?php endif; ?> 
			<cite class="author-name"><?php comment_author_link(); ?></cite>
		</div>
		<div class="comment-meta"><?php

printf(__('said on %1$s at %2$s:<br /><a href="%3$s" title="Permalink to this comment">Permalink</a>'), 
	get_comment_date(), 
	get_comment_time(), 
	'#comment-' . get_comment_ID()
);
comment_reply_link(array_merge($args, array('add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth'], 'before' => ' &bull; '))); edit_comment_link(__('Edit'), ' &bull; <span class="edit-link">', '</span>');

?>
<?php if ( 1 == $depth ) : ?><span class="c-number"><?php echo comment_number($comment_number); ?></span><?php endif; ?></div>
<?php if ( !$comment->comment_approved ) _e("\t\t" . '<div class="comment-unapproved">Your comment is awaiting moderation.</div>' . "\n"); ?>
		<div class="comment-body">
<?php comment_text(); ?>
		</div>
<?php else: /* This is a trackback */ ?>
<li id="trackback-<?php comment_ID(); ?>" <?php comment_class(empty($args['has_children']) ? '' : 'parent'); ?>>
	<div id="div-comment-<?php comment_ID(); ?>">
		<div class="comment-author">
<?php if ( function_exists('get_avatar') || function_exists('gravatar') ) : /* Trackbacks don't have gravatars but this is for a consistent look */ ?>
			<img class="author-gravatar left" src="<?php bloginfo('stylesheet_directory'); ?>/images/gravatar_trackback.gif" height="50" width="50" alt="<?php _e('Gravatar'); ?>" />
<?php endif; ?> 
			<cite class="author-name"><?php comment_author_link(); ?></cite>
		</div>
		<div class="comment-meta"><?php

printf(__('pinged on %1$s at %2$s.'), 
	get_comment_date(), 
	get_comment_time()
);
edit_comment_link(__('Edit'), '<br /><span class="edit-link">', '</span>');

?>
<?php if ( 1 == $depth ) : ?><span class="c-number"><?php echo comment_number($comment_number); ?></span><?php endif; ?></div>
<?php endif; ?>
	</div>
<?php
	
}

function comment_end($comment, $args, $depth) {
	
?>
</li>
<?php
	
}
/**#@-*/

/**
 * Displays the search form.
 * 
 * @param string $form_id The CSS identifier for this form.
 * @param string $text_id The CSS identifier for the text box.
 * @param string $submit_id The CSS identifier for the button.
 * @access public
 * @return void
 */
function searchform($form_id = 'searchform', $text_id = 's', $submit_id = 'searchsubmit') {
	$action    = attribute_escape(get_bloginfo('home'));
	$form_id   = attribute_escape($form_id);
	$text_id   = attribute_escape($text_id);
	$submit_id = attribute_escape($submit_id);
	
?>
<form action="<?php echo $action; ?>" id="<?php echo $form_id; ?>" class="searchform">
	<p class="center">
		<input type="text" name="s" id="<?php echo $text_id; ?>" class="s" value="<?php the_search_query(); ?>" />
		<button type="submit" name="searchsubmit" id="<?php echo $submit_id; ?>" class="searchsubmit"><?php echo attribute_escape(__('Go &rsaquo;')); ?></button>
	</p>
</form>
<?php
	
}

// Stop immediately if widgets aren't supported
if ( !function_exists('register_sidebar') )
	return;

register_sidebar();
register_sidebar_widget(__('Search'), 'widget_thistle_search', NULL, 'search');
unregister_widget_control('search');
register_sidebar_widget(__('Meta'), 'widget_thistle_meta', NULL, 'meta');
unregister_widget_control('meta');

/**
 * Search widget.
 * 
 * @param array $args
 * @access public
 * @return void
 */
function widget_thistle_search($args) {
	extract($args);
	if ( !$title )
		$title = __('Search');
	
	echo $before_widget, "\n", $before_title, $title, $after_title;
	searchform('searchform', 's', 'searchsubmit');
	echo $after_widget;
}

/**
 * Meta widget.
 * 
 * @param array $args
 * @access public
 * @return void
 */
function widget_thistle_meta($args) {
	extract($args);
	if ( !$title )
		$title = __('Meta');
	
	echo $before_widget, "\n", $before_title, $title, $after_title;
	
?>
						<ul>
							<?php wp_register(); ?> 
							<li><?php wp_loginout(); ?></li>
							<li><a href="http://validator.w3.org/check/referer" title="Valid XHTML 1.0 Transitional!">Valid <abbr title="eXtensible Hypertext Markup Language">XHTML</abbr></a></li>
							<li><a href="http://jigsaw.w3.org/css-validator/check/referer" title="Valid CSS!">Valid <abbr title="Cascading Style Sheets">CSS</abbr></a></li>
							<li><a href="http://gmpg.org/xfn"><abbr title="XHTML Friends Network">XFN</abbr></a></li>
							<li><a href="http://blog.NOVALISTIC.com/downloads/wordpress-themes/thistle">Thistle</a> theme by <a href="http://blog.NOVALISTIC.com">BoltClock</a></li>
							<li><a href="http://wordpress.org" title="Powered by WordPress, state-of-the-art semantic personal publishing platform.">WordPress</a></li>
							<?php wp_meta(); ?> 
						</ul>
<?php
	
	echo $after_widget;
}

?>